Parameters — Pywr 0.5dev documentation

# Parameters

## Base Parameter class

All the Parameter subclasses in pywr are descended from a common base class.

`Parameter` |
`IndexParameter` | Base parameter providing an index method

## Simple parameters

`ConstantParameter` |
`ConstantScenarioParameter` | A Scenario varying Parameter

## Combining multiple parameters

`AggregatedParameter` | A collection of IndexParameters
`AggregatedIndexParameter` | A collection of IndexParameters
`NegativeParameter` | Parameter that takes negative of another Parameter
`MaxParameter` | Parameter that takes maximum of another Parameter and constant value (threshold)
`NegativeMaxParameter` | Parameter that takes maximum of the negative of a Parameter and constant value (threshold)
`MinParameter` | Parameter that takes minimum of another Parameter and constant value (threshold)
`NegativeMinParameter` | Parameter that takes minimum of the negative of a Parameter and constant value (threshold)

## Annual profile parameters

`DailyProfileParameter` | An annual profile consisting of daily values.
`WeeklyProfileParameter` | Weekly profile (52-week year)
`MonthlyProfileParameter` | Parameter which provides a monthly profile
`ScenarioMonthlyProfileParameter` | Parameter which provides a monthly profile per scenario
`ArrayIndexedScenarioMonthlyFactorsParameter` | Time varying parameter using an array and Timestep._index with multiplicative factors per Scenario

## Dataframe parameter

`DataFrameParameter` | Timeseries parameter with automatic alignment and resampling

## HDF5 Parameter

`TablesArrayParameter` |

## Array based parameters

`ArrayIndexedParameter` | Time varying parameter using an array and Timestep._index
`ArrayIndexedScenarioParameter` | A Scenario varying Parameter
`IndexedArrayParameter` | Parameter which uses an IndexParameter to index an array of Parameters

## Control curve parameters

`control_curves.BaseControlCurveParameter` | Base class for all Parameters that rely on a the attached Node containing a control_curve Parameter
`control_curves.ControlCurveInterpolatedParameter` | A control curve Parameter that interpolates between three or more values
`control_curves.ControlCurveIndexParameter` | Multiple control curve holder which returns an index not a value

## Hydropower parameters

`HydropowerTargetParameter` | A parameter that returns flow from a hydropower generation target.

## Other parameters

`AnnualHarmonicSeriesParameter` | A Parameter which returns the value from an annual harmonic series
`DeficitParameter` | Parameter track the deficit (max_flow - actual flow) of a Node